@@ -1,4 +1,8 @@
-pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="Time", colConc="conc", dose=0, adm="Extravascular", dur=0, doseUnit="mg", timeUnit="h", concUnit="ug/L", down="Linear", R2ADJ=0, MW=0, iAUC="", excludeDelta=1)
+pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", 
+                  colTime="Time", colConc="conc", dose=0, adm="Extravascular", 
+                  dur=0, doseUnit="mg", timeUnit="h", concUnit="ug/L", 
+                  down="Linear", R2ADJ=0, MW=0, SS=FALSE, iAUC="", 
+                  excludeDelta=1)
 {
   class(concData) = "data.frame"
   defPar = par(no.readonly=TRUE)
@@ -36,7 +40,7 @@ pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="T
     if (nrow(tData) > 0) {
       x = tData[,colTime]
       y = tData[,colConc]
-      tabRes = sNCA(x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, R2ADJ=R2ADJ, MW=MW, iAUC=iAUC, Keystring=strHeader, excludeDelta=excludeDelta)
+      tabRes = sNCA(x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, R2ADJ=R2ADJ, MW=MW, SS=SS, iAUC=iAUC, Keystring=strHeader, excludeDelta=excludeDelta)
       UsedPoints = attr(tabRes, "UsedPoints")
       txtRes = Res2Txt(tabRes, x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, down=down)
       Res = c(Res, txtRes)
